@@ -10,24 +10,24 @@
 #ifndef ACCOUNTWIZARD_NO_GHNS
 #include "providerpage.h"
 #endif
-#include "typepage.h"
-#include "loadpage.h"
-#include "global.h"
+#include "cryptopage.h"
 #include "dynamicpage.h"
+#include "global.h"
+#include "loadpage.h"
 #include "servertest.h"
 #include "setuppage.h"
-#include "cryptopage.h"
+#include "typepage.h"
 
 #include <QAction>
 
 #include <KMime/Message>
 
-#include <KLocalizedString>
 #include "accountwizard_debug.h"
-#include <KMessageBox>
-#include <qplatformdefs.h>
 #include <KAboutData>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <PimCommon/PimUtil>
+#include <qplatformdefs.h>
 
 #include <KHelpMenu>
 
@@ -90,11 +90,11 @@ Dialog::Dialog(QWidget *parent)
 
     Page *page = qobject_cast<Page *>(currentPage()->widget());
     page->enterPageNext();
-    //TODO ? necessary ???
+    // TODO ? necessary ???
     Q_EMIT page->pageEnteredNext();
     connect(button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &Dialog::reject);
-    KHelpMenu *helpMenu = new KHelpMenu(this, KAboutData::applicationData(), true);
-    //Initialize menu
+    auto *helpMenu = new KHelpMenu(this, KAboutData::applicationData(), true);
+    // Initialize menu
     QMenu *menu = helpMenu->menu();
     helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(QIcon::fromTheme(QStringLiteral("akonadi")));
     disconnect(helpMenu->action(KHelpMenu::menuHelpContents), nullptr, helpMenu, nullptr);
@@ -153,7 +153,7 @@ void Dialog::slotBackOk()
 QObject *Dialog::addPage(const QString &uiFile, const QString &title)
 {
     qCDebug(ACCOUNTWIZARD_LOG) << uiFile;
-    DynamicPage *page = new DynamicPage(Global::assistantBasePath() + uiFile, this);
+    auto *page = new DynamicPage(Global::assistantBasePath() + uiFile, this);
     connect(page, &DynamicPage::leavePageNextOk, this, &Dialog::slotNextOk);
     connect(page, &DynamicPage::leavePageBackOk, this, &Dialog::slotBackOk);
     KPageWidgetItem *item = insertPage(mLastPage, page, title);
@@ -193,7 +193,9 @@ SetupManager *Dialog::setupManager()
 
 void Dialog::clearDynamicPages()
 {
-    foreach (KPageWidgetItem *item, mDynamicPages) {
+    const auto dynamicPages = mDynamicPages;
+    for (int i = 0, total = dynamicPages.count(); i < total; ++i) {
+        KPageWidgetItem *item = mDynamicPages.at(i);
         removePage(item);
     }
     mDynamicPages.clear();
@@ -201,7 +203,9 @@ void Dialog::clearDynamicPages()
 
 void Dialog::reject()
 {
-    connect(mSetupManager, &SetupManager::rollbackComplete, this, [this]() { KAssistantDialog::reject();} );
+    connect(mSetupManager, &SetupManager::rollbackComplete, this, [this]() {
+        KAssistantDialog::reject();
+    });
     mSetupManager->requestRollback();
 }
 
