@@ -1,12 +1,15 @@
 /*
-    SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "ldap.h"
-#include <KLDAP/LdapClientSearchConfig>
+#include "restoreldapsettingsjob.h"
 #include <KLDAP/AddHostDialog>
+#include <KLDAP/LdapClientSearchConfig>
+#include <KLDAP/LdapClientSearchConfigReadConfigJob>
+#include <KLDAP/LdapClientSearchConfigWriteConfigJob>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -15,14 +18,6 @@
 Ldap::Ldap(QObject *parent)
     : SetupObject(parent)
     , m_clientSearchConfig(new KLDAP::LdapClientSearchConfig)
-    , m_port(389)
-    , m_security(KLDAP::LdapServer::None)
-    , m_version(3)
-    , m_pageSize(0)
-    , m_timeLimit(0)
-    , m_sizeLimit(0)
-    , m_entry(-1)
-    , m_editMode(false)
 {
 }
 
@@ -38,7 +33,7 @@ KConfig *Ldap::config() const
 
 void Ldap::create()
 {
-    //TODO: use ldapclientsearchconfig to write config
+    // TODO: use ldapclientsearchconfig to write config
     Q_EMIT info(i18n("Setting up LDAP server..."));
 
     if (m_server.isEmpty()) {
@@ -78,8 +73,8 @@ void Ldap::create()
     KConfig *c = config();
     KConfigGroup group = c->group(QStringLiteral("LDAP"));
     bool hasMyServer = false;
-    uint selHosts = group.readEntry("NumSelectedHosts", 0);
-    for (uint i = 0; i < selHosts && !hasMyServer; ++i) {
+    const int selHosts = group.readEntry("NumSelectedHosts", 0);
+    for (int i = 0; i < selHosts && !hasMyServer; ++i) {
         if (group.readEntry(QStringLiteral("SelectedHost%1").arg(i), QString()) == host) {
             hasMyServer = true;
             m_entry = i;
@@ -132,10 +127,8 @@ QString Ldap::securityString()
         return QStringLiteral("SSL");
     case KLDAP::LdapServer::TLS:
         return QStringLiteral("TLS");
-    default:
-        Q_EMIT error(i18n("Unknown security setting for LDAP server"));
-        return QString();
     }
+    return {};
 }
 
 void Ldap::destroy()
@@ -143,44 +136,19 @@ void Ldap::destroy()
     Q_EMIT info(i18n("LDAP not configuring."));
     if (m_entry >= 0) {
         KConfig *c = config();
-        KConfigGroup group = c->group(QStringLiteral("LDAP"));
-        int cSelHosts = group.readEntry(QStringLiteral("NumSelectedHosts"), 0);
-        int cHosts = group.readEntry(QStringLiteral("NumHosts"), 0);
-        QVector<KLDAP::LdapServer> selHosts;
-        QVector<KLDAP::LdapServer> hosts;
-        for (int i = 0; i < cSelHosts; ++i) {
-            if (i != m_entry) {
-                KLDAP::LdapServer server;
-                m_clientSearchConfig->readConfig(server, group, i, true);
-                selHosts.append(server);
-            }
-        }
-        hosts.reserve(cHosts);
-        for (int i = 0; i < cHosts; ++i) {
-            KLDAP::LdapServer server;
-            m_clientSearchConfig->readConfig(server, group, i, false);
-            hosts.append(server);
-        }
-
-        c->deleteGroup(QStringLiteral("LDAP"));
-        group = KConfigGroup(c, QStringLiteral("LDAP"));
-
-        for (int i = 0; i < cSelHosts - 1; ++i) {
-            m_clientSearchConfig->writeConfig(selHosts.at(i), group, i, true);
-        }
-
-        for (int i = 0; i < cHosts; ++i) {
-            m_clientSearchConfig->writeConfig(hosts.at(i), group, i, false);
-        }
-
-        group.writeEntry(QStringLiteral("NumSelectedHosts"), cSelHosts - 1);
-        group.writeEntry(QStringLiteral("NumHosts"), cHosts);
-        c->sync();
-
-        Q_EMIT info(i18n("Removed LDAP entry."));
+        auto job = new RestoreLdapSettingsJob(this);
+        job->setEntry(m_entry);
+        job->setConfig(c);
+        connect(job, &RestoreLdapSettingsJob::restoreDone, this, &Ldap::slotRestoreDone);
+        job->start();
     }
 }
 
+void Ldap::slotRestoreDone()
+{
+    Q_EMIT info(i18n("Removed LDAP entry."));
+}
+
 void Ldap::edit()
 {
     if (m_entry < 0) {
@@ -191,12 +159,24 @@ void Ldap::edit()
     KLDAP::LdapServer server;
     KLDAP::LdapClientSearchConfig clientSearchConfig;
     KConfigGroup group = clientSearchConfig.config()->group(QStringLiteral("LDAP"));
-    clientSearchConfig.readConfig(server, group, m_entry, true);
-    KLDAP::AddHostDialog dlg(&server, nullptr);
 
-    if (dlg.exec() && !server.host().isEmpty()) { //krazy:exclude=crashy
-        clientSearchConfig.writeConfig(server, group, m_entry, true);
-    }
+    auto *job = new KLDAP::LdapClientSearchConfigReadConfigJob(this);
+    connect(job, &KLDAP::LdapClientSearchConfigReadConfigJob::configLoaded, this, [this, group](KLDAP::LdapServer server) {
+        KLDAP::AddHostDialog dlg(&server, nullptr);
+
+        if (dlg.exec() && !server.host().isEmpty()) { // krazy:exclude=crashy
+            auto job = new KLDAP::LdapClientSearchConfigWriteConfigJob;
+            job->setActive(true);
+            job->setConfig(group);
+            job->setServer(server);
+            job->setServerIndex(m_entry);
+            job->start();
+        }
+    });
+    job->setActive(true);
+    job->setConfig(group);
+    job->setServerIndex(m_entry);
+    job->start();
 }
 
 void Ldap::setUser(const QString &user)
